@@ -190,7 +190,7 @@ EXPLAIN SELECT * FROM tm1 t1, tm1 t2 WHERE t1.c1 = t2.c1;
 
 -- No. R-1-6-5
 \o results/R_1-6-5.out.log
-CREATE TABLE tmpcl WITH OIDS AS SELECT * from pg_catalog.pg_class limit 100;
+CREATE TABLE tmpcl WITH OIDS AS SELECT * from pg_catalog.pg_class LIMIT 100;
 ANALYZE tmpcl;
 EXPLAIN SELECT * FROM tmpcl t1, tmpcl t2 WHERE t1.oid = t2.oid;
 /*+Rows(t1 t2 #1)*/
